@@ -1,12 +1,18 @@
 package Graphics::Primitive::Driver::Cairo::TextLayout;
+{
+  $Graphics::Primitive::Driver::Cairo::TextLayout::VERSION = '0.44';
+}
 use Moose;
 
+# ABSTRCAT: Text layout engine
+
 use Graphics::Primitive::TextBox;
 
 with 'Graphics::Primitive::Driver::TextLayout';
 
 use Text::Flow;
 
+
 has 'lines' => (
     is => 'rw',
     isa => 'ArrayRef',
@@ -123,15 +129,25 @@ __PACKAGE__->meta->make_immutable;
 
 no Moose;
 1;
+
 __END__
+=pod
+
 =head1 NAME
 
-Graphics::Primitive::Driver::Cairo::TextLayout - Text layout engine
+Graphics::Primitive::Driver::Cairo::TextLayout
+
+=head1 VERSION
+
+version 0.44
 
 =head1 SYNOPSIS
 
+    my $driver = Graphics::Primitive::Driver::Cairo->new(format => 'PDF');
+
+    my $comp = Graphics::Primitive::TextBox->new;
+
     my $tl = $driver->get_textbox_layout($comp);
-    ...
 
 =head1 DESCRIPTION
 
@@ -145,17 +161,14 @@ layout text.
 
 =head1 AUTHOR
 
-Cory Watson, C<< <gphat@cpan.org> >>
+Cory G Watson <gphat@cpan.org>
 
-=head1 BUGS
+=head1 COPYRIGHT AND LICENSE
 
-Please report any bugs or feature requests to C<bug-geometry-primitive at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Geometry-Primitive>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
+This software is copyright (c) 2011 by Cold Hard Code, LLC.
 
-=head1 COPYRIGHT & LICENSE
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
-Copyright 2010 by Cory G Watson
+=cut
 
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
